@@ -2,10 +2,6 @@ package testcases::base;
 use strict;
 use warnings;
 
-use Test::Unit::Lite;
-use Encode;
-use Spreadsheet::Write;
-
 use base qw(XAO::testcases::base);
 
 ###############################################################################
